@@ -341,10 +341,10 @@ class SimultanObject(object, metaclass=MetaMock):
 
         self._slot_components = None
 
-        if self._create_all:
-            _ = self.contained_components
-            _ = self.contained_parameters
-            _ = self.referenced_components
+        # if self._create_all:
+        #     _ = self.contained_components
+        #     _ = self.contained_parameters
+        #     _ = self.referenced_components
 
         # _ = self.slot_components
 
@@ -804,9 +804,9 @@ class List(UserList):
         self._template_parser = kwargs.get('template_parser', None)
         self._data_model_id = kwargs.get('data_model_id', None)
 
-        if self._create_all:
-            _ = self.contained_components
-            _ = self.contained_parameters
+        # if self._create_all:
+        #     _ = self.contained_components
+        #     _ = self.contained_parameters
 
     @property
     def data(self):
