@@ -65,7 +65,7 @@ class Template(object):
         @keyword units: units of the content. Dictionary
         @keyword types: Dictionary with the type of the content. if the type is 'str' get_TextValue() is returned, param.get_ValueCurrent() otherwise
         @keyword slots: Dictionary with the name of the content and the name of the slot where it is expected. The expected slot is a string
-        @keyword default_slot: Default slot name for the Simultan component
+        @keyword default_slot: Default slot name for the Simultan component when new created
         with the slot name and the extension, seperated by a blank
         """
 
@@ -474,9 +474,9 @@ def add_properties(prop_name: str, syn_name: str, param_type: str, slot=None) ->
                            None)
 
                 if obj is None:
-                    obj = next((x.get_Reference() for x in self._wrapped_obj.ReferencedComponents.Items
-                                if ' '.join([str(x.ReferenceFunction.SlotBase),
-                                             x.ReferenceFunction.SlotExtension]) == full_slot_name),
+                    obj = next((x.Target for x in self._wrapped_obj.ReferencedComponents.Items
+                                if ' '.join([str(x.Slot.SlotBase),
+                                             x.Slot.SlotExtension]) == full_slot_name),
                                None)
 
         return self._template_parser.create_python_object(obj)
@@ -516,8 +516,8 @@ def add_properties(prop_name: str, syn_name: str, param_type: str, slot=None) ->
                 # if reference:
                 elif self.slot_components.iloc[idx].comp_type.values == 1:
                     ref = next((x for x in self._wrapped_obj.ReferencedComponents.Items
-                                if ((x.ReferenceFunction.SlotBase.Base == slot_name) & (
-                                x.ReferenceFunction.SlotExtension == slot_extension))), None)
+                                if ((x.Slot.SlotBase.Base == slot_name) & (
+                                x.Slot.SlotExtension == slot_extension))), None)
 
                     if isinstance(value, SimComponent):
                         # delete reference
