@@ -256,12 +256,12 @@ def sort_references(references):
     if references.__len__() == 0:
         return references
     # check if same slot:
-    slots = [x.ReferenceFunction.SlotBase for x in references]
+    slots = [x.Slot.SlotBase for x in references]
 
     if not all(slots[0] == x for x in slots):
         raise TypeError(f'List elements do not have same slot')
 
-    slot_extensions = [int(x.ReferenceFunction.SlotExtension) for x in references]
+    slot_extensions = [int(x.Slot.SlotExtension) for x in references]
     return slot_extensions
 
 
@@ -276,7 +276,11 @@ def parse_slot(full_slot_name: str) -> Tuple[str, any]:
     :param full_slot_name:
     :return: (slot_name, slot_extension)
     """
-    slot_extension = full_slot_name.split()[-1]
-    slot_name = ' '.join(full_slot_name.split()[0:-1])
+    if full_slot_name.startswith('Undefined Slot'):
+        slot_extension = full_slot_name.split('_')[-1]
+        slot_name = 'Undefined Slot'
+    else:
+        slot_extension = full_slot_name.split()[-1]
+        slot_name = ' '.join(full_slot_name.split()[0:-1])
 
     return slot_name, slot_extension
